@@ -13,7 +13,7 @@
 # limitations under the License.
 
 from servz.base.utilities.parser.parser import Parser
-from servz.base.project_config import ProjectConfig
+from servz.project_config import ProjectConfig
 
 
 class CmdConfigParser(Parser):
