@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from servz.base.utilities.parser.parser import Parser
-from servz.base.project_config import ProjectConfig
+from servz.project_config import ProjectConfig
 
 
 class ConfigParser(Parser):
