@@ -12,18 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from typing import NamedTuple
-from servz.core.workflow_validator.workflow_validator import WorkflowValidator
-from servz.core.pipline_composer.pipeline_composer import PipelineComposer
-from servz.core.orchestration_artifact_builder.orchestration_artifact_builder import OrchestrationArtifactBuilder
-from servz.core.endpoint_appender.endpoint_appender import EndpointAppender
-from servz.core.packager.packager import Packager
-from servz.core.package_publisher.package_publisher import PackagePublisher
+
+from servz.base.packager.packager import Packager
+from servz.base.pipline_composer.pipeline_composer import PipelineComposer
+from servz.base.workflow_validator.workflow_validator import WorkflowValidator
 
 
 class BuildPipeline(NamedTuple):
     workflow_validator: WorkflowValidator
     pipeline_composer: PipelineComposer
-    deployment_artifact_builder: OrchestrationArtifactBuilder
-    endpoint_appender: EndpointAppender
     packager: Packager
-    package_publisher: PackagePublisher
