@@ -13,8 +13,9 @@
 # limitations under the License.
 import yaml
 from providah.factories.package_factory import PackageFactory as pf
+
 from servz.core.build_pipeline import BuildPipeline
-from servz.utils.parsers.project_config import ProjectConfig
+from servz.project_config import ProjectConfig
 
 
 class Builder:
@@ -36,26 +37,14 @@ class Builder:
         if self.__path:
             configuration['workflow_validation']['conf']['project_path'] = self.__path
             configuration['pipeline_composition']['conf']['project_path'] = self.__path
-            configuration['orchestration_artifact_builder']['conf']['project_path'] = self.__path
-            configuration['endpoint_appender']['conf']['project_path'] = self.__path
             configuration['packager']['conf']['project_path'] = self.__path
-            configuration['package_publisher']['conf']['project_path'] = self.__path
 
-        self.__build_pipeline.workflow_validator = pf.create(key=configuration['workflow_validation']['type'],
+        self.__build_pipeline.workflow_validator = pf.create( key=configuration['workflow_validation']['type'],
                                                          configuration=configuration['workflow_validation']['conf'])
 
         self.__build_pipeline.pipeline_composer = pf.create(key=configuration['pipeline_composition']['type'],
                                                             configuration=configuration['pipeline_composition']['conf'])
 
-        self.__build_pipeline.deployment_artifact_builder = pf.create(key=configuration['orchestration_artifact_builder']['type'],
-                                                                      configuration=configuration['orchestration_artifact_builder']['conf'])
-
-        self.__build_pipeline.endpoint_appender = pf.create(key=configuration['endpoint_appender']['type'],
-                                                            configuration=configuration['endpoint_appender']['conf'])
-
         self.__build_pipeline.packager = pf.create(key=configuration['packager']['type'],
                                                    configuration=configuration['packager']['conf'])
 
-        self.__build_pipeline.package_publisher = pf.create(key=configuration['package_publisher']['type'],
-                                                            configuration=configuration['package_publisher']['conf'])
-
